# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'business_object_format_version': 'int',
        'partition_value': 'str',
        'sub_partition_values': 'list[str]',
        'business_object_data_version': 'int',
        'reason': 'str'
    }

    attribute_map = {
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value': 'partitionValue',
        'sub_partition_values': 'subPartitionValues',
        'business_object_data_version': 'businessObjectDataVersion',
        'reason': 'reason'
    }

    def __init__(self, business_object_format_version=None, partition_value=None, sub_partition_values=None, business_object_data_version=None, reason=None):  # noqa: E501
        """BusinessObjectDataStatus - a model defined in OpenAPI"""  # noqa: E501

        self._business_object_format_version = None
        self._partition_value = None
        self._sub_partition_values = None
        self._business_object_data_version = None
        self._reason = None
        self.discriminator = None

        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        self.partition_value = partition_value
        if sub_partition_values is not None:
            self.sub_partition_values = sub_partition_values
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if reason is not None:
            self.reason = reason

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataStatus.  # noqa: E501

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectDataStatus.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataStatus.

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataStatus.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value(self):
        """Gets the partition_value of this BusinessObjectDataStatus.  # noqa: E501

        The partition value that the Business Object Data is associated with  # noqa: E501

        :return: The partition_value of this BusinessObjectDataStatus.  # noqa: E501
        :rtype: str
        """
        return self._partition_value

    @partition_value.setter
    def partition_value(self, partition_value):
        """Sets the partition_value of this BusinessObjectDataStatus.

        The partition value that the Business Object Data is associated with  # noqa: E501

        :param partition_value: The partition_value of this BusinessObjectDataStatus.  # noqa: E501
        :type: str
        """
        if partition_value is None:
            raise ValueError("Invalid value for `partition_value`, must not be `None`")  # noqa: E501

        self._partition_value = partition_value

    @property
    def sub_partition_values(self):
        """Gets the sub_partition_values of this BusinessObjectDataStatus.  # noqa: E501

        A list of Sub-Partition values associated with a Business Object Data  # noqa: E501

        :return: The sub_partition_values of this BusinessObjectDataStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._sub_partition_values

    @sub_partition_values.setter
    def sub_partition_values(self, sub_partition_values):
        """Sets the sub_partition_values of this BusinessObjectDataStatus.

        A list of Sub-Partition values associated with a Business Object Data  # noqa: E501

        :param sub_partition_values: The sub_partition_values of this BusinessObjectDataStatus.  # noqa: E501
        :type: list[str]
        """

        self._sub_partition_values = sub_partition_values

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataStatus.  # noqa: E501

        The numeric version of a Business Object Data  # noqa: E501

        :return: The business_object_data_version of this BusinessObjectDataStatus.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataStatus.

        The numeric version of a Business Object Data  # noqa: E501

        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataStatus.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def reason(self):
        """Gets the reason of this BusinessObjectDataStatus.  # noqa: E501

        A reason for the Business Object Data not being available (NOT_REGISTERED, INVALID, etc...)  # noqa: E501

        :return: The reason of this BusinessObjectDataStatus.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this BusinessObjectDataStatus.

        A reason for the Business Object Data not being available (NOT_REGISTERED, INVALID, etc...)  # noqa: E501

        :param reason: The reason of this BusinessObjectDataStatus.  # noqa: E501
        :type: str
        """

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class IndexSearchKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tag_key': 'TagKey',
        'index_search_result_type_key': 'IndexSearchResultTypeKey',
        'include_tag_hierarchy': 'bool'
    }

    attribute_map = {
        'tag_key': 'tagKey',
        'index_search_result_type_key': 'indexSearchResultTypeKey',
        'include_tag_hierarchy': 'includeTagHierarchy'
    }

    def __init__(self, tag_key=None, index_search_result_type_key=None, include_tag_hierarchy=None):  # noqa: E501
        """IndexSearchKey - a model defined in OpenAPI"""  # noqa: E501

        self._tag_key = None
        self._index_search_result_type_key = None
        self._include_tag_hierarchy = None
        self.discriminator = None

        if tag_key is not None:
            self.tag_key = tag_key
        if index_search_result_type_key is not None:
            self.index_search_result_type_key = index_search_result_type_key
        if include_tag_hierarchy is not None:
            self.include_tag_hierarchy = include_tag_hierarchy

    @property
    def tag_key(self):
        """Gets the tag_key of this IndexSearchKey.  # noqa: E501


        :return: The tag_key of this IndexSearchKey.  # noqa: E501
        :rtype: TagKey
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this IndexSearchKey.


        :param tag_key: The tag_key of this IndexSearchKey.  # noqa: E501
        :type: TagKey
        """

        self._tag_key = tag_key

    @property
    def index_search_result_type_key(self):
        """Gets the index_search_result_type_key of this IndexSearchKey.  # noqa: E501


        :return: The index_search_result_type_key of this IndexSearchKey.  # noqa: E501
        :rtype: IndexSearchResultTypeKey
        """
        return self._index_search_result_type_key

    @index_search_result_type_key.setter
    def index_search_result_type_key(self, index_search_result_type_key):
        """Sets the index_search_result_type_key of this IndexSearchKey.


        :param index_search_result_type_key: The index_search_result_type_key of this IndexSearchKey.  # noqa: E501
        :type: IndexSearchResultTypeKey
        """

        self._index_search_result_type_key = index_search_result_type_key

    @property
    def include_tag_hierarchy(self):
        """Gets the include_tag_hierarchy of this IndexSearchKey.  # noqa: E501

        An optional boolean flag that specifies if business object definition associated with entire tag hierarchy is to be retrieved                  # noqa: E501

        :return: The include_tag_hierarchy of this IndexSearchKey.  # noqa: E501
        :rtype: bool
        """
        return self._include_tag_hierarchy

    @include_tag_hierarchy.setter
    def include_tag_hierarchy(self, include_tag_hierarchy):
        """Sets the include_tag_hierarchy of this IndexSearchKey.

        An optional boolean flag that specifies if business object definition associated with entire tag hierarchy is to be retrieved                  # noqa: E501

        :param include_tag_hierarchy: The include_tag_hierarchy of this IndexSearchKey.  # noqa: E501
        :type: bool
        """

        self._include_tag_hierarchy = include_tag_hierarchy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndexSearchKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class DownloadSingleInitiationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'business_object_data': 'BusinessObjectData',
        'aws_access_key': 'str',
        'aws_secret_key': 'str',
        'aws_session_token': 'str',
        'aws_session_expiration_time': 'datetime',
        'pre_signed_url': 'str'
    }

    attribute_map = {
        'business_object_data': 'businessObjectData',
        'aws_access_key': 'awsAccessKey',
        'aws_secret_key': 'awsSecretKey',
        'aws_session_token': 'awsSessionToken',
        'aws_session_expiration_time': 'awsSessionExpirationTime',
        'pre_signed_url': 'preSignedUrl'
    }

    def __init__(self, business_object_data=None, aws_access_key=None, aws_secret_key=None, aws_session_token=None, aws_session_expiration_time=None, pre_signed_url=None):  # noqa: E501
        """DownloadSingleInitiationResponse - a model defined in OpenAPI"""  # noqa: E501

        self._business_object_data = None
        self._aws_access_key = None
        self._aws_secret_key = None
        self._aws_session_token = None
        self._aws_session_expiration_time = None
        self._pre_signed_url = None
        self.discriminator = None

        self.business_object_data = business_object_data
        self.aws_access_key = aws_access_key
        self.aws_secret_key = aws_secret_key
        self.aws_session_token = aws_session_token
        self.aws_session_expiration_time = aws_session_expiration_time
        self.pre_signed_url = pre_signed_url

    @property
    def business_object_data(self):
        """Gets the business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: BusinessObjectData
        """
        return self._business_object_data

    @business_object_data.setter
    def business_object_data(self, business_object_data):
        """Sets the business_object_data of this DownloadSingleInitiationResponse.


        :param business_object_data: The business_object_data of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: BusinessObjectData
        """
        if business_object_data is None:
            raise ValueError("Invalid value for `business_object_data`, must not be `None`")  # noqa: E501

        self._business_object_data = business_object_data

    @property
    def aws_access_key(self):
        """Gets the aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_key

    @aws_access_key.setter
    def aws_access_key(self, aws_access_key):
        """Sets the aws_access_key of this DownloadSingleInitiationResponse.


        :param aws_access_key: The aws_access_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_access_key is None:
            raise ValueError("Invalid value for `aws_access_key`, must not be `None`")  # noqa: E501

        self._aws_access_key = aws_access_key

    @property
    def aws_secret_key(self):
        """Gets the aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_secret_key

    @aws_secret_key.setter
    def aws_secret_key(self, aws_secret_key):
        """Sets the aws_secret_key of this DownloadSingleInitiationResponse.


        :param aws_secret_key: The aws_secret_key of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_secret_key is None:
            raise ValueError("Invalid value for `aws_secret_key`, must not be `None`")  # noqa: E501

        self._aws_secret_key = aws_secret_key

    @property
    def aws_session_token(self):
        """Gets the aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._aws_session_token

    @aws_session_token.setter
    def aws_session_token(self, aws_session_token):
        """Sets the aws_session_token of this DownloadSingleInitiationResponse.


        :param aws_session_token: The aws_session_token of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if aws_session_token is None:
            raise ValueError("Invalid value for `aws_session_token`, must not be `None`")  # noqa: E501

        self._aws_session_token = aws_session_token

    @property
    def aws_session_expiration_time(self):
        """Gets the aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._aws_session_expiration_time

    @aws_session_expiration_time.setter
    def aws_session_expiration_time(self, aws_session_expiration_time):
        """Sets the aws_session_expiration_time of this DownloadSingleInitiationResponse.


        :param aws_session_expiration_time: The aws_session_expiration_time of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: datetime
        """
        if aws_session_expiration_time is None:
            raise ValueError("Invalid value for `aws_session_expiration_time`, must not be `None`")  # noqa: E501

        self._aws_session_expiration_time = aws_session_expiration_time

    @property
    def pre_signed_url(self):
        """Gets the pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501


        :return: The pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501
        :rtype: str
        """
        return self._pre_signed_url

    @pre_signed_url.setter
    def pre_signed_url(self, pre_signed_url):
        """Sets the pre_signed_url of this DownloadSingleInitiationResponse.


        :param pre_signed_url: The pre_signed_url of this DownloadSingleInitiationResponse.  # noqa: E501
        :type: str
        """
        if pre_signed_url is None:
            raise ValueError("Invalid value for `pre_signed_url`, must not be `None`")  # noqa: E501

        self._pre_signed_url = pre_signed_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DownloadSingleInitiationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class StoragePolicyFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'storage_name': 'str',
        'do_not_transition_latest_valid': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'storage_name': 'storageName',
        'do_not_transition_latest_valid': 'doNotTransitionLatestValid'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, storage_name=None, do_not_transition_latest_valid=None):  # noqa: E501
        """StoragePolicyFilter - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._storage_name = None
        self._do_not_transition_latest_valid = None
        self.discriminator = None

        if namespace is not None:
            self.namespace = namespace
        if business_object_definition_name is not None:
            self.business_object_definition_name = business_object_definition_name
        if business_object_format_usage is not None:
            self.business_object_format_usage = business_object_format_usage
        if business_object_format_file_type is not None:
            self.business_object_format_file_type = business_object_format_file_type
        self.storage_name = storage_name
        if do_not_transition_latest_valid is not None:
            self.do_not_transition_latest_valid = do_not_transition_latest_valid

    @property
    def namespace(self):
        """Gets the namespace of this StoragePolicyFilter.  # noqa: E501

        The namespace of the registered business object definition. It is required when businessObjectDefinitionName is present                  # noqa: E501

        :return: The namespace of this StoragePolicyFilter.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this StoragePolicyFilter.

        The namespace of the registered business object definition. It is required when businessObjectDefinitionName is present                  # noqa: E501

        :param namespace: The namespace of this StoragePolicyFilter.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this StoragePolicyFilter.  # noqa: E501

        The name of the registered business object definition. It is required when namespace is present  # noqa: E501

        :return: The business_object_definition_name of this StoragePolicyFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this StoragePolicyFilter.

        The name of the registered business object definition. It is required when namespace is present  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this StoragePolicyFilter.  # noqa: E501
        :type: str
        """

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this StoragePolicyFilter.  # noqa: E501

        The business object format usage. The usage does not need to exist in the system. It is required when                   businessObjectFormatFileType is present                  # noqa: E501

        :return: The business_object_format_usage of this StoragePolicyFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this StoragePolicyFilter.

        The business object format usage. The usage does not need to exist in the system. It is required when                   businessObjectFormatFileType is present                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this StoragePolicyFilter.  # noqa: E501
        :type: str
        """

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this StoragePolicyFilter.  # noqa: E501

        The business object format file type. The file type must be known by the system. It is required when businessObjectFormatUsage                   is present                  # noqa: E501

        :return: The business_object_format_file_type of this StoragePolicyFilter.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this StoragePolicyFilter.

        The business object format file type. The file type must be known by the system. It is required when businessObjectFormatUsage                   is present                  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this StoragePolicyFilter.  # noqa: E501
        :type: str
        """

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def storage_name(self):
        """Gets the storage_name of this StoragePolicyFilter.  # noqa: E501

        The name of the storage that this storage policy applies to. The storage with this name must already exist. Currently, only S3                   storage platform type is supported by the storage policies                  # noqa: E501

        :return: The storage_name of this StoragePolicyFilter.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this StoragePolicyFilter.

        The name of the storage that this storage policy applies to. The storage with this name must already exist. Currently, only S3                   storage platform type is supported by the storage policies                  # noqa: E501

        :param storage_name: The storage_name of this StoragePolicyFilter.  # noqa: E501
        :type: str
        """
        if storage_name is None:
            raise ValueError("Invalid value for `storage_name`, must not be `None`")  # noqa: E501

        self._storage_name = storage_name

    @property
    def do_not_transition_latest_valid(self):
        """Gets the do_not_transition_latest_valid of this StoragePolicyFilter.  # noqa: E501

        If true, this storage policy will not transition latest valid business object data versions  # noqa: E501

        :return: The do_not_transition_latest_valid of this StoragePolicyFilter.  # noqa: E501
        :rtype: bool
        """
        return self._do_not_transition_latest_valid

    @do_not_transition_latest_valid.setter
    def do_not_transition_latest_valid(self, do_not_transition_latest_valid):
        """Sets the do_not_transition_latest_valid of this StoragePolicyFilter.

        If true, this storage policy will not transition latest valid business object data versions  # noqa: E501

        :param do_not_transition_latest_valid: The do_not_transition_latest_valid of this StoragePolicyFilter.  # noqa: E501
        :type: bool
        """

        self._do_not_transition_latest_valid = do_not_transition_latest_valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoragePolicyFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class KeyValuePairConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key_value_shortcut': 'str',
        'attrib_key': 'str',
        'attrib_val': 'str'
    }

    attribute_map = {
        'key_value_shortcut': 'keyValueShortcut',
        'attrib_key': 'attribKey',
        'attrib_val': 'attribVal'
    }

    def __init__(self, key_value_shortcut=None, attrib_key=None, attrib_val=None):  # noqa: E501
        """KeyValuePairConfiguration - a model defined in OpenAPI"""  # noqa: E501

        self._key_value_shortcut = None
        self._attrib_key = None
        self._attrib_val = None
        self.discriminator = None

        self.key_value_shortcut = key_value_shortcut
        self.attrib_key = attrib_key
        self.attrib_val = attrib_val

    @property
    def key_value_shortcut(self):
        """Gets the key_value_shortcut of this KeyValuePairConfiguration.  # noqa: E501


        :return: The key_value_shortcut of this KeyValuePairConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._key_value_shortcut

    @key_value_shortcut.setter
    def key_value_shortcut(self, key_value_shortcut):
        """Sets the key_value_shortcut of this KeyValuePairConfiguration.


        :param key_value_shortcut: The key_value_shortcut of this KeyValuePairConfiguration.  # noqa: E501
        :type: str
        """
        if key_value_shortcut is None:
            raise ValueError("Invalid value for `key_value_shortcut`, must not be `None`")  # noqa: E501

        self._key_value_shortcut = key_value_shortcut

    @property
    def attrib_key(self):
        """Gets the attrib_key of this KeyValuePairConfiguration.  # noqa: E501


        :return: The attrib_key of this KeyValuePairConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._attrib_key

    @attrib_key.setter
    def attrib_key(self, attrib_key):
        """Sets the attrib_key of this KeyValuePairConfiguration.


        :param attrib_key: The attrib_key of this KeyValuePairConfiguration.  # noqa: E501
        :type: str
        """
        if attrib_key is None:
            raise ValueError("Invalid value for `attrib_key`, must not be `None`")  # noqa: E501

        self._attrib_key = attrib_key

    @property
    def attrib_val(self):
        """Gets the attrib_val of this KeyValuePairConfiguration.  # noqa: E501


        :return: The attrib_val of this KeyValuePairConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._attrib_val

    @attrib_val.setter
    def attrib_val(self, attrib_val):
        """Sets the attrib_val of this KeyValuePairConfiguration.


        :param attrib_val: The attrib_val of this KeyValuePairConfiguration.  # noqa: E501
        :type: str
        """
        if attrib_val is None:
            raise ValueError("Invalid value for `attrib_val`, must not be `None`")  # noqa: E501

        self._attrib_val = attrib_val

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeyValuePairConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SearchIndexStatistics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index_creation_date': 'datetime',
        'index_number_of_active_documents': 'int',
        'index_number_of_deleted_documents': 'int',
        'index_uuid': 'str',
        'index_count': 'int'
    }

    attribute_map = {
        'index_creation_date': 'indexCreationDate',
        'index_number_of_active_documents': 'indexNumberOfActiveDocuments',
        'index_number_of_deleted_documents': 'indexNumberOfDeletedDocuments',
        'index_uuid': 'indexUuid',
        'index_count': 'indexCount'
    }

    def __init__(self, index_creation_date=None, index_number_of_active_documents=None, index_number_of_deleted_documents=None, index_uuid=None, index_count=None):  # noqa: E501
        """SearchIndexStatistics - a model defined in OpenAPI"""  # noqa: E501

        self._index_creation_date = None
        self._index_number_of_active_documents = None
        self._index_number_of_deleted_documents = None
        self._index_uuid = None
        self._index_count = None
        self.discriminator = None

        if index_creation_date is not None:
            self.index_creation_date = index_creation_date
        if index_number_of_active_documents is not None:
            self.index_number_of_active_documents = index_number_of_active_documents
        if index_number_of_deleted_documents is not None:
            self.index_number_of_deleted_documents = index_number_of_deleted_documents
        if index_uuid is not None:
            self.index_uuid = index_uuid
        if index_count is not None:
            self.index_count = index_count

    @property
    def index_creation_date(self):
        """Gets the index_creation_date of this SearchIndexStatistics.  # noqa: E501

        The index creation date  # noqa: E501

        :return: The index_creation_date of this SearchIndexStatistics.  # noqa: E501
        :rtype: datetime
        """
        return self._index_creation_date

    @index_creation_date.setter
    def index_creation_date(self, index_creation_date):
        """Sets the index_creation_date of this SearchIndexStatistics.

        The index creation date  # noqa: E501

        :param index_creation_date: The index_creation_date of this SearchIndexStatistics.  # noqa: E501
        :type: datetime
        """

        self._index_creation_date = index_creation_date

    @property
    def index_number_of_active_documents(self):
        """Gets the index_number_of_active_documents of this SearchIndexStatistics.  # noqa: E501

        The number of active documents in this index  # noqa: E501

        :return: The index_number_of_active_documents of this SearchIndexStatistics.  # noqa: E501
        :rtype: int
        """
        return self._index_number_of_active_documents

    @index_number_of_active_documents.setter
    def index_number_of_active_documents(self, index_number_of_active_documents):
        """Sets the index_number_of_active_documents of this SearchIndexStatistics.

        The number of active documents in this index  # noqa: E501

        :param index_number_of_active_documents: The index_number_of_active_documents of this SearchIndexStatistics.  # noqa: E501
        :type: int
        """

        self._index_number_of_active_documents = index_number_of_active_documents

    @property
    def index_number_of_deleted_documents(self):
        """Gets the index_number_of_deleted_documents of this SearchIndexStatistics.  # noqa: E501

        The number of deleted documents in this index  # noqa: E501

        :return: The index_number_of_deleted_documents of this SearchIndexStatistics.  # noqa: E501
        :rtype: int
        """
        return self._index_number_of_deleted_documents

    @index_number_of_deleted_documents.setter
    def index_number_of_deleted_documents(self, index_number_of_deleted_documents):
        """Sets the index_number_of_deleted_documents of this SearchIndexStatistics.

        The number of deleted documents in this index  # noqa: E501

        :param index_number_of_deleted_documents: The index_number_of_deleted_documents of this SearchIndexStatistics.  # noqa: E501
        :type: int
        """

        self._index_number_of_deleted_documents = index_number_of_deleted_documents

    @property
    def index_uuid(self):
        """Gets the index_uuid of this SearchIndexStatistics.  # noqa: E501

        The UUID of the index  # noqa: E501

        :return: The index_uuid of this SearchIndexStatistics.  # noqa: E501
        :rtype: str
        """
        return self._index_uuid

    @index_uuid.setter
    def index_uuid(self, index_uuid):
        """Sets the index_uuid of this SearchIndexStatistics.

        The UUID of the index  # noqa: E501

        :param index_uuid: The index_uuid of this SearchIndexStatistics.  # noqa: E501
        :type: str
        """

        self._index_uuid = index_uuid

    @property
    def index_count(self):
        """Gets the index_count of this SearchIndexStatistics.  # noqa: E501

        The count of the index size from count query  # noqa: E501

        :return: The index_count of this SearchIndexStatistics.  # noqa: E501
        :rtype: int
        """
        return self._index_count

    @index_count.setter
    def index_count(self, index_count):
        """Sets the index_count of this SearchIndexStatistics.

        The count of the index size from count query  # noqa: E501

        :param index_count: The index_count of this SearchIndexStatistics.  # noqa: E501
        :type: int
        """

        self._index_count = index_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchIndexStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Facet(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'facet_display_name': 'str',
        'facet_count': 'int',
        'facet_type': 'str',
        'facet_id': 'str',
        'facets': 'list[Facet]'
    }

    attribute_map = {
        'facet_display_name': 'facetDisplayName',
        'facet_count': 'facetCount',
        'facet_type': 'facetType',
        'facet_id': 'facetId',
        'facets': 'facets'
    }

    def __init__(self, facet_display_name=None, facet_count=None, facet_type=None, facet_id=None, facets=None):  # noqa: E501
        """Facet - a model defined in OpenAPI"""  # noqa: E501

        self._facet_display_name = None
        self._facet_count = None
        self._facet_type = None
        self._facet_id = None
        self._facets = None
        self.discriminator = None

        if facet_display_name is not None:
            self.facet_display_name = facet_display_name
        if facet_count is not None:
            self.facet_count = facet_count
        if facet_type is not None:
            self.facet_type = facet_type
        if facet_id is not None:
            self.facet_id = facet_id
        if facets is not None:
            self.facets = facets

    @property
    def facet_display_name(self):
        """Gets the facet_display_name of this Facet.  # noqa: E501

        Display name of the facet  # noqa: E501

        :return: The facet_display_name of this Facet.  # noqa: E501
        :rtype: str
        """
        return self._facet_display_name

    @facet_display_name.setter
    def facet_display_name(self, facet_display_name):
        """Sets the facet_display_name of this Facet.

        Display name of the facet  # noqa: E501

        :param facet_display_name: The facet_display_name of this Facet.  # noqa: E501
        :type: str
        """

        self._facet_display_name = facet_display_name

    @property
    def facet_count(self):
        """Gets the facet_count of this Facet.  # noqa: E501

        count of the facet  # noqa: E501

        :return: The facet_count of this Facet.  # noqa: E501
        :rtype: int
        """
        return self._facet_count

    @facet_count.setter
    def facet_count(self, facet_count):
        """Sets the facet_count of this Facet.

        count of the facet  # noqa: E501

        :param facet_count: The facet_count of this Facet.  # noqa: E501
        :type: int
        """

        self._facet_count = facet_count

    @property
    def facet_type(self):
        """Gets the facet_type of this Facet.  # noqa: E501

        Type of the facet  # noqa: E501

        :return: The facet_type of this Facet.  # noqa: E501
        :rtype: str
        """
        return self._facet_type

    @facet_type.setter
    def facet_type(self, facet_type):
        """Sets the facet_type of this Facet.

        Type of the facet  # noqa: E501

        :param facet_type: The facet_type of this Facet.  # noqa: E501
        :type: str
        """

        self._facet_type = facet_type

    @property
    def facet_id(self):
        """Gets the facet_id of this Facet.  # noqa: E501

        unique identifier of the facet  # noqa: E501

        :return: The facet_id of this Facet.  # noqa: E501
        :rtype: str
        """
        return self._facet_id

    @facet_id.setter
    def facet_id(self, facet_id):
        """Sets the facet_id of this Facet.

        unique identifier of the facet  # noqa: E501

        :param facet_id: The facet_id of this Facet.  # noqa: E501
        :type: str
        """

        self._facet_id = facet_id

    @property
    def facets(self):
        """Gets the facets of this Facet.  # noqa: E501

        list of facets  # noqa: E501

        :return: The facets of this Facet.  # noqa: E501
        :rtype: list[Facet]
        """
        return self._facets

    @facets.setter
    def facets(self, facets):
        """Sets the facets of this Facet.

        list of facets  # noqa: E501

        :param facets: The facets of this Facet.  # noqa: E501
        :type: list[Facet]
        """

        self._facets = facets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Facet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class BusinessObjectFormatExternalInterfaceDescriptiveInformationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, **kwargs):  # noqa: E501
        """getBusinessObjectFormatExternalInterface  # noqa: E501

        Retrieves the existing business object format external interface descriptive information based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param str external_interface_name: the external interface name (required)
        :return: BusinessObjectFormatExternalInterfaceDescriptiveInformation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, **kwargs)  # noqa: E501
            return data

    def business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface_with_http_info(self, namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, **kwargs):  # noqa: E501
        """getBusinessObjectFormatExternalInterface  # noqa: E501

        Retrieves the existing business object format external interface descriptive information based on the specified parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface_with_http_info(namespace, business_object_definition_name, business_object_format_usage, business_object_format_file_type, external_interface_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str business_object_format_usage: the business object format usage (required)
        :param str business_object_format_file_type: the business object format file type (required)
        :param str external_interface_name: the external interface name (required)
        :return: BusinessObjectFormatExternalInterfaceDescriptiveInformation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'business_object_format_usage', 'business_object_format_file_type', 'external_interface_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface`")  # noqa: E501
        # verify the required parameter 'business_object_format_usage' is set
        if ('business_object_format_usage' not in local_var_params or
                local_var_params['business_object_format_usage'] is None):
            raise ValueError("Missing the required parameter `business_object_format_usage` when calling `business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface`")  # noqa: E501
        # verify the required parameter 'business_object_format_file_type' is set
        if ('business_object_format_file_type' not in local_var_params or
                local_var_params['business_object_format_file_type'] is None):
            raise ValueError("Missing the required parameter `business_object_format_file_type` when calling `business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface`")  # noqa: E501
        # verify the required parameter 'external_interface_name' is set
        if ('external_interface_name' not in local_var_params or
                local_var_params['external_interface_name'] is None):
            raise ValueError("Missing the required parameter `external_interface_name` when calling `business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'business_object_format_usage' in local_var_params:
            path_params['businessObjectFormatUsage'] = local_var_params['business_object_format_usage']  # noqa: E501
        if 'business_object_format_file_type' in local_var_params:
            path_params['businessObjectFormatFileType'] = local_var_params['business_object_format_file_type']  # noqa: E501
        if 'external_interface_name' in local_var_params:
            path_params['externalInterfaceName'] = local_var_params['external_interface_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectFormatExternalInterfaceDescriptiveInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/externalInterfaceNames/{externalInterfaceName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectFormatExternalInterfaceDescriptiveInformation',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class WorkflowError(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error_message': 'str',
        'retries_left': 'int',
        'error_stack_trace': 'str'
    }

    attribute_map = {
        'error_message': 'errorMessage',
        'retries_left': 'retriesLeft',
        'error_stack_trace': 'errorStackTrace'
    }

    def __init__(self, error_message=None, retries_left=None, error_stack_trace=None):  # noqa: E501
        """WorkflowError - a model defined in OpenAPI"""  # noqa: E501

        self._error_message = None
        self._retries_left = None
        self._error_stack_trace = None
        self.discriminator = None

        self.error_message = error_message
        if retries_left is not None:
            self.retries_left = retries_left
        if error_stack_trace is not None:
            self.error_stack_trace = error_stack_trace

    @property
    def error_message(self):
        """Gets the error_message of this WorkflowError.  # noqa: E501

        Error message  # noqa: E501

        :return: The error_message of this WorkflowError.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this WorkflowError.

        Error message  # noqa: E501

        :param error_message: The error_message of this WorkflowError.  # noqa: E501
        :type: str
        """
        if error_message is None:
            raise ValueError("Invalid value for `error_message`, must not be `None`")  # noqa: E501

        self._error_message = error_message

    @property
    def retries_left(self):
        """Gets the retries_left of this WorkflowError.  # noqa: E501

        Number of retries left  # noqa: E501

        :return: The retries_left of this WorkflowError.  # noqa: E501
        :rtype: int
        """
        return self._retries_left

    @retries_left.setter
    def retries_left(self, retries_left):
        """Sets the retries_left of this WorkflowError.

        Number of retries left  # noqa: E501

        :param retries_left: The retries_left of this WorkflowError.  # noqa: E501
        :type: int
        """

        self._retries_left = retries_left

    @property
    def error_stack_trace(self):
        """Gets the error_stack_trace of this WorkflowError.  # noqa: E501

        The error stack trace  # noqa: E501

        :return: The error_stack_trace of this WorkflowError.  # noqa: E501
        :rtype: str
        """
        return self._error_stack_trace

    @error_stack_trace.setter
    def error_stack_trace(self, error_stack_trace):
        """Sets the error_stack_trace of this WorkflowError.

        The error stack trace  # noqa: E501

        :param error_stack_trace: The error_stack_trace of this WorkflowError.  # noqa: E501
        :type: str
        """

        self._error_stack_trace = error_stack_trace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionDescriptionSuggestion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'business_object_definition_description_suggestion_key': 'BusinessObjectDefinitionDescriptionSuggestionKey',
        'description_suggestion': 'str',
        'status': 'str',
        'created_by_user_id': 'str',
        'created_on': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'business_object_definition_description_suggestion_key': 'businessObjectDefinitionDescriptionSuggestionKey',
        'description_suggestion': 'descriptionSuggestion',
        'status': 'status',
        'created_by_user_id': 'createdByUserId',
        'created_on': 'createdOn'
    }

    def __init__(self, id=None, business_object_definition_description_suggestion_key=None, description_suggestion=None, status=None, created_by_user_id=None, created_on=None):  # noqa: E501
        """BusinessObjectDefinitionDescriptionSuggestion - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._business_object_definition_description_suggestion_key = None
        self._description_suggestion = None
        self._status = None
        self._created_by_user_id = None
        self._created_on = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.business_object_definition_description_suggestion_key = business_object_definition_description_suggestion_key
        if description_suggestion is not None:
            self.description_suggestion = description_suggestion
        if status is not None:
            self.status = status
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if created_on is not None:
            self.created_on = created_on

    @property
    def id(self):
        """Gets the id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        A system unique ID of this business object definition description suggestion  # noqa: E501

        :return: The id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BusinessObjectDefinitionDescriptionSuggestion.

        A system unique ID of this business object definition description suggestion  # noqa: E501

        :param id: The id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def business_object_definition_description_suggestion_key(self):
        """Gets the business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501


        :return: The business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: BusinessObjectDefinitionDescriptionSuggestionKey
        """
        return self._business_object_definition_description_suggestion_key

    @business_object_definition_description_suggestion_key.setter
    def business_object_definition_description_suggestion_key(self, business_object_definition_description_suggestion_key):
        """Sets the business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.


        :param business_object_definition_description_suggestion_key: The business_object_definition_description_suggestion_key of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: BusinessObjectDefinitionDescriptionSuggestionKey
        """
        if business_object_definition_description_suggestion_key is None:
            raise ValueError("Invalid value for `business_object_definition_description_suggestion_key`, must not be `None`")  # noqa: E501

        self._business_object_definition_description_suggestion_key = business_object_definition_description_suggestion_key

    @property
    def description_suggestion(self):
        """Gets the description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The description suggestion  # noqa: E501

        :return: The description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._description_suggestion

    @description_suggestion.setter
    def description_suggestion(self, description_suggestion):
        """Sets the description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.

        The description suggestion  # noqa: E501

        :param description_suggestion: The description_suggestion of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._description_suggestion = description_suggestion

    @property
    def status(self):
        """Gets the status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The status of the business object definition description suggestion. One of the following values: PENDING, ACCEPTED                  # noqa: E501

        :return: The status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BusinessObjectDefinitionDescriptionSuggestion.

        The status of the business object definition description suggestion. One of the following values: PENDING, ACCEPTED                  # noqa: E501

        :param status: The status of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The User ID of the user who created this business object definition description suggestion  # noqa: E501

        :return: The created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.

        The User ID of the user who created this business object definition description suggestion  # noqa: E501

        :param created_by_user_id: The created_by_user_id of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: str
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_on(self):
        """Gets the created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501

        The timestamp when this business object definition description suggestion was created on  # noqa: E501

        :return: The created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this BusinessObjectDefinitionDescriptionSuggestion.

        The timestamp when this business object definition description suggestion was created on  # noqa: E501

        :param created_on: The created_on of this BusinessObjectDefinitionDescriptionSuggestion.  # noqa: E501
        :type: datetime
        """

        self._created_on = created_on

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionDescriptionSuggestion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_notification_registration_api import BusinessObjectDataNotificationRegistrationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataNotificationRegistrationApi(unittest.TestCase):
    """BusinessObjectDataNotificationRegistrationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_notification_registration_api.BusinessObjectDataNotificationRegistrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_notification_registration_create_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_create_business_object_data_notification_registration

        createBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_delete_business_object_data_notification(self):
        """Test case for business_object_data_notification_registration_delete_business_object_data_notification

        deleteBusinessObjectDataNotification  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registration

        getBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace

        getBusinessObjectDataNotificationRegistrationsByNamespace  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter(self):
        """Test case for business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter

        getBusinessObjectDataNotificationRegistrationsByNotificationFilter  # noqa: E501
        """
        pass

    def test_business_object_data_notification_registration_update_business_object_data_notification_registration(self):
        """Test case for business_object_data_notification_registration_update_business_object_data_notification_registration

        updateBusinessObjectDataNotificationRegistration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class UploadSingleInitiationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_business_object_format_key': 'BusinessObjectFormatKey',
        'target_business_object_format_key': 'BusinessObjectFormatKey',
        'business_object_data_attributes': 'list[Attribute]',
        'file': 'file',
        'target_storage_name': 'str'
    }

    attribute_map = {
        'source_business_object_format_key': 'sourceBusinessObjectFormatKey',
        'target_business_object_format_key': 'targetBusinessObjectFormatKey',
        'business_object_data_attributes': 'businessObjectDataAttributes',
        'file': 'file',
        'target_storage_name': 'targetStorageName'
    }

    def __init__(self, source_business_object_format_key=None, target_business_object_format_key=None, business_object_data_attributes=None, file=None, target_storage_name=None):  # noqa: E501
        """UploadSingleInitiationRequest - a model defined in OpenAPI"""  # noqa: E501

        self._source_business_object_format_key = None
        self._target_business_object_format_key = None
        self._business_object_data_attributes = None
        self._file = None
        self._target_storage_name = None
        self.discriminator = None

        self.source_business_object_format_key = source_business_object_format_key
        self.target_business_object_format_key = target_business_object_format_key
        if business_object_data_attributes is not None:
            self.business_object_data_attributes = business_object_data_attributes
        self.file = file
        if target_storage_name is not None:
            self.target_storage_name = target_storage_name

    @property
    def source_business_object_format_key(self):
        """Gets the source_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501


        :return: The source_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501
        :rtype: BusinessObjectFormatKey
        """
        return self._source_business_object_format_key

    @source_business_object_format_key.setter
    def source_business_object_format_key(self, source_business_object_format_key):
        """Sets the source_business_object_format_key of this UploadSingleInitiationRequest.


        :param source_business_object_format_key: The source_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501
        :type: BusinessObjectFormatKey
        """
        if source_business_object_format_key is None:
            raise ValueError("Invalid value for `source_business_object_format_key`, must not be `None`")  # noqa: E501

        self._source_business_object_format_key = source_business_object_format_key

    @property
    def target_business_object_format_key(self):
        """Gets the target_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501


        :return: The target_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501
        :rtype: BusinessObjectFormatKey
        """
        return self._target_business_object_format_key

    @target_business_object_format_key.setter
    def target_business_object_format_key(self, target_business_object_format_key):
        """Sets the target_business_object_format_key of this UploadSingleInitiationRequest.


        :param target_business_object_format_key: The target_business_object_format_key of this UploadSingleInitiationRequest.  # noqa: E501
        :type: BusinessObjectFormatKey
        """
        if target_business_object_format_key is None:
            raise ValueError("Invalid value for `target_business_object_format_key`, must not be `None`")  # noqa: E501

        self._target_business_object_format_key = target_business_object_format_key

    @property
    def business_object_data_attributes(self):
        """Gets the business_object_data_attributes of this UploadSingleInitiationRequest.  # noqa: E501

        The business object data attributes  # noqa: E501

        :return: The business_object_data_attributes of this UploadSingleInitiationRequest.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._business_object_data_attributes

    @business_object_data_attributes.setter
    def business_object_data_attributes(self, business_object_data_attributes):
        """Sets the business_object_data_attributes of this UploadSingleInitiationRequest.

        The business object data attributes  # noqa: E501

        :param business_object_data_attributes: The business_object_data_attributes of this UploadSingleInitiationRequest.  # noqa: E501
        :type: list[Attribute]
        """

        self._business_object_data_attributes = business_object_data_attributes

    @property
    def file(self):
        """Gets the file of this UploadSingleInitiationRequest.  # noqa: E501


        :return: The file of this UploadSingleInitiationRequest.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this UploadSingleInitiationRequest.


        :param file: The file of this UploadSingleInitiationRequest.  # noqa: E501
        :type: file
        """
        if file is None:
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def target_storage_name(self):
        """Gets the target_storage_name of this UploadSingleInitiationRequest.  # noqa: E501

        The target storage name to move the encrypted file to  # noqa: E501

        :return: The target_storage_name of this UploadSingleInitiationRequest.  # noqa: E501
        :rtype: str
        """
        return self._target_storage_name

    @target_storage_name.setter
    def target_storage_name(self, target_storage_name):
        """Sets the target_storage_name of this UploadSingleInitiationRequest.

        The target storage name to move the encrypted file to  # noqa: E501

        :param target_storage_name: The target_storage_name of this UploadSingleInitiationRequest.  # noqa: E501
        :type: str
        """

        self._target_storage_name = target_storage_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadSingleInitiationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SchemaColumn(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'size': 'str',
        'required': 'bool',
        'default_value': 'str',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'size': 'size',
        'required': 'required',
        'default_value': 'defaultValue',
        'description': 'description'
    }

    def __init__(self, name=None, type=None, size=None, required=None, default_value=None, description=None):  # noqa: E501
        """SchemaColumn - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._type = None
        self._size = None
        self._required = None
        self._default_value = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.type = type
        if size is not None:
            self.size = size
        if required is not None:
            self.required = required
        if default_value is not None:
            self.default_value = default_value
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this SchemaColumn.  # noqa: E501

        The name of the schema column. Required when Column is present  # noqa: E501

        :return: The name of this SchemaColumn.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SchemaColumn.

        The name of the schema column. Required when Column is present  # noqa: E501

        :param name: The name of this SchemaColumn.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this SchemaColumn.  # noqa: E501

        The data type of the schema column. Required when Column is present  # noqa: E501

        :return: The type of this SchemaColumn.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SchemaColumn.

        The data type of the schema column. Required when Column is present  # noqa: E501

        :param type: The type of this SchemaColumn.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def size(self):
        """Gets the size of this SchemaColumn.  # noqa: E501

        The column size. This is a string value since, for \"NUMERIC\" and \"DECIMAL\" data types, we should be able to specify both                   the maximum number of digits (p) that are present in the number and the maximum number of decimal places (s) as a \"p,s\" string. Required when                   Column is present                  # noqa: E501

        :return: The size of this SchemaColumn.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SchemaColumn.

        The column size. This is a string value since, for \"NUMERIC\" and \"DECIMAL\" data types, we should be able to specify both                   the maximum number of digits (p) that are present in the number and the maximum number of decimal places (s) as a \"p,s\" string. Required when                   Column is present                  # noqa: E501

        :param size: The size of this SchemaColumn.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def required(self):
        """Gets the required of this SchemaColumn.  # noqa: E501

        Values true|false. If true, a value isis required for the column (not nullable)  # noqa: E501

        :return: The required of this SchemaColumn.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this SchemaColumn.

        Values true|false. If true, a value isis required for the column (not nullable)  # noqa: E501

        :param required: The required of this SchemaColumn.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def default_value(self):
        """Gets the default_value of this SchemaColumn.  # noqa: E501

        Default value for the column  # noqa: E501

        :return: The default_value of this SchemaColumn.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this SchemaColumn.

        Default value for the column  # noqa: E501

        :param default_value: The default_value of this SchemaColumn.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def description(self):
        """Gets the description of this SchemaColumn.  # noqa: E501

        Description of the column  # noqa: E501

        :return: The description of this SchemaColumn.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SchemaColumn.

        Description of the column  # noqa: E501

        :param description: The description of this SchemaColumn.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemaColumn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataDdl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value_filters': 'list[PartitionValueFilter]',
        'partition_value_filter': 'PartitionValueFilter',
        'business_object_data_version': 'int',
        'business_object_data_status': 'str',
        'storage_names': 'list[str]',
        'storage_name': 'str',
        'output_format': 'str',
        'table_name': 'str',
        'custom_ddl_name': 'str',
        'ddl': 'str',
        'as_of_time': 'datetime'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value_filters': 'partitionValueFilters',
        'partition_value_filter': 'partitionValueFilter',
        'business_object_data_version': 'businessObjectDataVersion',
        'business_object_data_status': 'businessObjectDataStatus',
        'storage_names': 'storageNames',
        'storage_name': 'storageName',
        'output_format': 'outputFormat',
        'table_name': 'tableName',
        'custom_ddl_name': 'customDdlName',
        'ddl': 'ddl',
        'as_of_time': 'asOfTime'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value_filters=None, partition_value_filter=None, business_object_data_version=None, business_object_data_status=None, storage_names=None, storage_name=None, output_format=None, table_name=None, custom_ddl_name=None, ddl=None, as_of_time=None):  # noqa: E501
        """BusinessObjectDataDdl - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value_filters = None
        self._partition_value_filter = None
        self._business_object_data_version = None
        self._business_object_data_status = None
        self._storage_names = None
        self._storage_name = None
        self._output_format = None
        self._table_name = None
        self._custom_ddl_name = None
        self._ddl = None
        self._as_of_time = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if partition_value_filters is not None:
            self.partition_value_filters = partition_value_filters
        if partition_value_filter is not None:
            self.partition_value_filter = partition_value_filter
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if business_object_data_status is not None:
            self.business_object_data_status = business_object_data_status
        if storage_names is not None:
            self.storage_names = storage_names
        if storage_name is not None:
            self.storage_name = storage_name
        self.output_format = output_format
        self.table_name = table_name
        if custom_ddl_name is not None:
            self.custom_ddl_name = custom_ddl_name
        self.ddl = ddl
        if as_of_time is not None:
            self.as_of_time = as_of_time

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataDdl.  # noqa: E501


        :return: The namespace of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataDdl.


        :param namespace: The namespace of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataDdl.  # noqa: E501


        :return: The business_object_definition_name of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataDdl.


        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataDdl.  # noqa: E501


        :return: The business_object_format_usage of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataDdl.


        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataDdl.  # noqa: E501


        :return: The business_object_format_file_type of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataDdl.


        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataDdl.  # noqa: E501


        :return: The business_object_format_version of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataDdl.


        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataDdl.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value_filters(self):
        """Gets the partition_value_filters of this BusinessObjectDataDdl.  # noqa: E501


        :return: The partition_value_filters of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: list[PartitionValueFilter]
        """
        return self._partition_value_filters

    @partition_value_filters.setter
    def partition_value_filters(self, partition_value_filters):
        """Sets the partition_value_filters of this BusinessObjectDataDdl.


        :param partition_value_filters: The partition_value_filters of this BusinessObjectDataDdl.  # noqa: E501
        :type: list[PartitionValueFilter]
        """

        self._partition_value_filters = partition_value_filters

    @property
    def partition_value_filter(self):
        """Gets the partition_value_filter of this BusinessObjectDataDdl.  # noqa: E501


        :return: The partition_value_filter of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: PartitionValueFilter
        """
        return self._partition_value_filter

    @partition_value_filter.setter
    def partition_value_filter(self, partition_value_filter):
        """Sets the partition_value_filter of this BusinessObjectDataDdl.


        :param partition_value_filter: The partition_value_filter of this BusinessObjectDataDdl.  # noqa: E501
        :type: PartitionValueFilter
        """

        self._partition_value_filter = partition_value_filter

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataDdl.  # noqa: E501


        :return: The business_object_data_version of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataDdl.


        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataDdl.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def business_object_data_status(self):
        """Gets the business_object_data_status of this BusinessObjectDataDdl.  # noqa: E501

        A Business Object Data Status value specified in the request for available Business Object Data  # noqa: E501

        :return: The business_object_data_status of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._business_object_data_status

    @business_object_data_status.setter
    def business_object_data_status(self, business_object_data_status):
        """Sets the business_object_data_status of this BusinessObjectDataDdl.

        A Business Object Data Status value specified in the request for available Business Object Data  # noqa: E501

        :param business_object_data_status: The business_object_data_status of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """

        self._business_object_data_status = business_object_data_status

    @property
    def storage_names(self):
        """Gets the storage_names of this BusinessObjectDataDdl.  # noqa: E501


        :return: The storage_names of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_names

    @storage_names.setter
    def storage_names(self, storage_names):
        """Sets the storage_names of this BusinessObjectDataDdl.


        :param storage_names: The storage_names of this BusinessObjectDataDdl.  # noqa: E501
        :type: list[str]
        """

        self._storage_names = storage_names

    @property
    def storage_name(self):
        """Gets the storage_name of this BusinessObjectDataDdl.  # noqa: E501


        :return: The storage_name of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this BusinessObjectDataDdl.


        :param storage_name: The storage_name of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """

        self._storage_name = storage_name

    @property
    def output_format(self):
        """Gets the output_format of this BusinessObjectDataDdl.  # noqa: E501


        :return: The output_format of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._output_format

    @output_format.setter
    def output_format(self, output_format):
        """Sets the output_format of this BusinessObjectDataDdl.


        :param output_format: The output_format of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if output_format is None:
            raise ValueError("Invalid value for `output_format`, must not be `None`")  # noqa: E501
        allowed_values = ["HIVE_13_DDL"]  # noqa: E501
        if output_format not in allowed_values:
            raise ValueError(
                "Invalid value for `output_format` ({0}), must be one of {1}"  # noqa: E501
                .format(output_format, allowed_values)
            )

        self._output_format = output_format

    @property
    def table_name(self):
        """Gets the table_name of this BusinessObjectDataDdl.  # noqa: E501


        :return: The table_name of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this BusinessObjectDataDdl.


        :param table_name: The table_name of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if table_name is None:
            raise ValueError("Invalid value for `table_name`, must not be `None`")  # noqa: E501

        self._table_name = table_name

    @property
    def custom_ddl_name(self):
        """Gets the custom_ddl_name of this BusinessObjectDataDdl.  # noqa: E501


        :return: The custom_ddl_name of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._custom_ddl_name

    @custom_ddl_name.setter
    def custom_ddl_name(self, custom_ddl_name):
        """Sets the custom_ddl_name of this BusinessObjectDataDdl.


        :param custom_ddl_name: The custom_ddl_name of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """

        self._custom_ddl_name = custom_ddl_name

    @property
    def ddl(self):
        """Gets the ddl of this BusinessObjectDataDdl.  # noqa: E501


        :return: The ddl of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: str
        """
        return self._ddl

    @ddl.setter
    def ddl(self, ddl):
        """Sets the ddl of this BusinessObjectDataDdl.


        :param ddl: The ddl of this BusinessObjectDataDdl.  # noqa: E501
        :type: str
        """
        if ddl is None:
            raise ValueError("Invalid value for `ddl`, must not be `None`")  # noqa: E501

        self._ddl = ddl

    @property
    def as_of_time(self):
        """Gets the as_of_time of this BusinessObjectDataDdl.  # noqa: E501


        :return: The as_of_time of this BusinessObjectDataDdl.  # noqa: E501
        :rtype: datetime
        """
        return self._as_of_time

    @as_of_time.setter
    def as_of_time(self, as_of_time):
        """Sets the as_of_time of this BusinessObjectDataDdl.


        :param as_of_time: The as_of_time of this BusinessObjectDataDdl.  # noqa: E501
        :type: datetime
        """

        self._as_of_time = as_of_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataDdl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Schema(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'columns': 'list[SchemaColumn]',
        'partitions': 'list[SchemaColumn]',
        'null_value': 'str',
        'delimiter': 'str',
        'collection_items_delimiter': 'str',
        'map_keys_delimiter': 'str',
        'escape_character': 'str',
        'custom_row_format': 'str',
        'custom_clustered_by': 'str',
        'custom_tbl_properties': 'str',
        'partition_key_group': 'str'
    }

    attribute_map = {
        'columns': 'columns',
        'partitions': 'partitions',
        'null_value': 'nullValue',
        'delimiter': 'delimiter',
        'collection_items_delimiter': 'collectionItemsDelimiter',
        'map_keys_delimiter': 'mapKeysDelimiter',
        'escape_character': 'escapeCharacter',
        'custom_row_format': 'customRowFormat',
        'custom_clustered_by': 'customClusteredBy',
        'custom_tbl_properties': 'customTblProperties',
        'partition_key_group': 'partitionKeyGroup'
    }

    def __init__(self, columns=None, partitions=None, null_value=None, delimiter=None, collection_items_delimiter=None, map_keys_delimiter=None, escape_character=None, custom_row_format=None, custom_clustered_by=None, custom_tbl_properties=None, partition_key_group=None):  # noqa: E501
        """Schema - a model defined in OpenAPI"""  # noqa: E501

        self._columns = None
        self._partitions = None
        self._null_value = None
        self._delimiter = None
        self._collection_items_delimiter = None
        self._map_keys_delimiter = None
        self._escape_character = None
        self._custom_row_format = None
        self._custom_clustered_by = None
        self._custom_tbl_properties = None
        self._partition_key_group = None
        self.discriminator = None

        if columns is not None:
            self.columns = columns
        if partitions is not None:
            self.partitions = partitions
        if null_value is not None:
            self.null_value = null_value
        if delimiter is not None:
            self.delimiter = delimiter
        if collection_items_delimiter is not None:
            self.collection_items_delimiter = collection_items_delimiter
        if map_keys_delimiter is not None:
            self.map_keys_delimiter = map_keys_delimiter
        if escape_character is not None:
            self.escape_character = escape_character
        if custom_row_format is not None:
            self.custom_row_format = custom_row_format
        if custom_clustered_by is not None:
            self.custom_clustered_by = custom_clustered_by
        if custom_tbl_properties is not None:
            self.custom_tbl_properties = custom_tbl_properties
        if partition_key_group is not None:
            self.partition_key_group = partition_key_group

    @property
    def columns(self):
        """Gets the columns of this Schema.  # noqa: E501

        A container for Schema Columns that are present in data file(s) for this Business Object Format. Required when Schema is                   present                  # noqa: E501

        :return: The columns of this Schema.  # noqa: E501
        :rtype: list[SchemaColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this Schema.

        A container for Schema Columns that are present in data file(s) for this Business Object Format. Required when Schema is                   present                  # noqa: E501

        :param columns: The columns of this Schema.  # noqa: E501
        :type: list[SchemaColumn]
        """

        self._columns = columns

    @property
    def partitions(self):
        """Gets the partitions of this Schema.  # noqa: E501

        A container for partition columns in a specific schema. A schema might have zero, one or more partition columns. If a partition                   column is present in the data file(s), it should also be listed as a regular column in the schema with all column information matching (case                   sensitive)                  # noqa: E501

        :return: The partitions of this Schema.  # noqa: E501
        :rtype: list[SchemaColumn]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this Schema.

        A container for partition columns in a specific schema. A schema might have zero, one or more partition columns. If a partition                   column is present in the data file(s), it should also be listed as a regular column in the schema with all column information matching (case                   sensitive)                  # noqa: E501

        :param partitions: The partitions of this Schema.  # noqa: E501
        :type: list[SchemaColumn]
        """

        self._partitions = partitions

    @property
    def null_value(self):
        """Gets the null_value of this Schema.  # noqa: E501

        The string to use for the null value (e.g. \"\\\\\\\\N\"). Please note that a null value is allowed to be a whitespace character.                   XML escaping should be used when specifying non-ASCII characters.                   Note: when passing in an empty String, the response XML will return a NULL value (i.e. the tag will be absent). Generate DDL calls will show                   the correct empty String value wrapped in single-quotes.                   Required when Schema is present                  # noqa: E501

        :return: The null_value of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._null_value

    @null_value.setter
    def null_value(self, null_value):
        """Sets the null_value of this Schema.

        The string to use for the null value (e.g. \"\\\\\\\\N\"). Please note that a null value is allowed to be a whitespace character.                   XML escaping should be used when specifying non-ASCII characters.                   Note: when passing in an empty String, the response XML will return a NULL value (i.e. the tag will be absent). Generate DDL calls will show                   the correct empty String value wrapped in single-quotes.                   Required when Schema is present                  # noqa: E501

        :param null_value: The null_value of this Schema.  # noqa: E501
        :type: str
        """

        self._null_value = null_value

    @property
    def delimiter(self):
        """Gets the delimiter of this Schema.  # noqa: E501

        The field delimiter (e.g. \"|\"). Please note that a field delimiter is allowed to be a whitespace character.                   XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :return: The delimiter of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this Schema.

        The field delimiter (e.g. \"|\"). Please note that a field delimiter is allowed to be a whitespace character.                   XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :param delimiter: The delimiter of this Schema.  # noqa: E501
        :type: str
        """

        self._delimiter = delimiter

    @property
    def collection_items_delimiter(self):
        """Gets the collection_items_delimiter of this Schema.  # noqa: E501

        The collection items delimiter (e.g. \",\"). XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :return: The collection_items_delimiter of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._collection_items_delimiter

    @collection_items_delimiter.setter
    def collection_items_delimiter(self, collection_items_delimiter):
        """Sets the collection_items_delimiter of this Schema.

        The collection items delimiter (e.g. \",\"). XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :param collection_items_delimiter: The collection_items_delimiter of this Schema.  # noqa: E501
        :type: str
        """

        self._collection_items_delimiter = collection_items_delimiter

    @property
    def map_keys_delimiter(self):
        """Gets the map_keys_delimiter of this Schema.  # noqa: E501

        The map keys delimiter (e.g. \"=\"). XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :return: The map_keys_delimiter of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._map_keys_delimiter

    @map_keys_delimiter.setter
    def map_keys_delimiter(self, map_keys_delimiter):
        """Sets the map_keys_delimiter of this Schema.

        The map keys delimiter (e.g. \"=\"). XML escaping should be used when specifying non-ASCII characters                  # noqa: E501

        :param map_keys_delimiter: The map_keys_delimiter of this Schema.  # noqa: E501
        :type: str
        """

        self._map_keys_delimiter = map_keys_delimiter

    @property
    def escape_character(self):
        """Gets the escape_character of this Schema.  # noqa: E501

        The escape character (e.g. \"\\\\\\\\\").                   XML escaping should be used when specifying non-ASCII characters.                  # noqa: E501

        :return: The escape_character of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._escape_character

    @escape_character.setter
    def escape_character(self, escape_character):
        """Sets the escape_character of this Schema.

        The escape character (e.g. \"\\\\\\\\\").                   XML escaping should be used when specifying non-ASCII characters.                  # noqa: E501

        :param escape_character: The escape_character of this Schema.  # noqa: E501
        :type: str
        """

        self._escape_character = escape_character

    @property
    def custom_row_format(self):
        """Gets the custom_row_format of this Schema.  # noqa: E501

        The customRowFormat is used for defining custom Hive format.                   This will override everything after \"ROW FORMAT\" in DDL including delimiter, escape value, null value statements                  # noqa: E501

        :return: The custom_row_format of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._custom_row_format

    @custom_row_format.setter
    def custom_row_format(self, custom_row_format):
        """Sets the custom_row_format of this Schema.

        The customRowFormat is used for defining custom Hive format.                   This will override everything after \"ROW FORMAT\" in DDL including delimiter, escape value, null value statements                  # noqa: E501

        :param custom_row_format: The custom_row_format of this Schema.  # noqa: E501
        :type: str
        """

        self._custom_row_format = custom_row_format

    @property
    def custom_clustered_by(self):
        """Gets the custom_clustered_by of this Schema.  # noqa: E501

        The customClusteredBy is used to support Hive \"CLUSTERED BY\" statement                  # noqa: E501

        :return: The custom_clustered_by of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._custom_clustered_by

    @custom_clustered_by.setter
    def custom_clustered_by(self, custom_clustered_by):
        """Sets the custom_clustered_by of this Schema.

        The customClusteredBy is used to support Hive \"CLUSTERED BY\" statement                  # noqa: E501

        :param custom_clustered_by: The custom_clustered_by of this Schema.  # noqa: E501
        :type: str
        """

        self._custom_clustered_by = custom_clustered_by

    @property
    def custom_tbl_properties(self):
        """Gets the custom_tbl_properties of this Schema.  # noqa: E501

        The customTblProperties is used to support Hive \"TBLPROPERTIES\" statement and tag the Hive table definition with your own                   metadata key/value pairs                  # noqa: E501

        :return: The custom_tbl_properties of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._custom_tbl_properties

    @custom_tbl_properties.setter
    def custom_tbl_properties(self, custom_tbl_properties):
        """Sets the custom_tbl_properties of this Schema.

        The customTblProperties is used to support Hive \"TBLPROPERTIES\" statement and tag the Hive table definition with your own                   metadata key/value pairs                  # noqa: E501

        :param custom_tbl_properties: The custom_tbl_properties of this Schema.  # noqa: E501
        :type: str
        """

        self._custom_tbl_properties = custom_tbl_properties

    @property
    def partition_key_group(self):
        """Gets the partition_key_group of this Schema.  # noqa: E501

        The partition key group that this schema's partition or sub-partition key belongs to. This value will be used to identify the                   ordered set of Expected Partition Values when determining Business Object Data Availability or generating DDL using partition value ranges. A                   Partition Key Group value is required in the Business Object Format in order to use partition value ranges with the Availability and DDL                   services                  # noqa: E501

        :return: The partition_key_group of this Schema.  # noqa: E501
        :rtype: str
        """
        return self._partition_key_group

    @partition_key_group.setter
    def partition_key_group(self, partition_key_group):
        """Sets the partition_key_group of this Schema.

        The partition key group that this schema's partition or sub-partition key belongs to. This value will be used to identify the                   ordered set of Expected Partition Values when determining Business Object Data Availability or generating DDL using partition value ranges. A                   Partition Key Group value is required in the Business Object Format in order to use partition value ranges with the Availability and DDL                   services                  # noqa: E501

        :param partition_key_group: The partition_key_group of this Schema.  # noqa: E501
        :type: str
        """

        self._partition_key_group = partition_key_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Schema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataAvailability(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value_filters': 'list[PartitionValueFilter]',
        'partition_value_filter': 'PartitionValueFilter',
        'business_object_data_version': 'int',
        'business_object_data_status': 'str',
        'storage_names': 'list[str]',
        'storage_name': 'str',
        'available_statuses': 'list[BusinessObjectDataStatus]',
        'not_available_statuses': 'list[BusinessObjectDataStatus]'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value_filters': 'partitionValueFilters',
        'partition_value_filter': 'partitionValueFilter',
        'business_object_data_version': 'businessObjectDataVersion',
        'business_object_data_status': 'businessObjectDataStatus',
        'storage_names': 'storageNames',
        'storage_name': 'storageName',
        'available_statuses': 'availableStatuses',
        'not_available_statuses': 'notAvailableStatuses'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value_filters=None, partition_value_filter=None, business_object_data_version=None, business_object_data_status=None, storage_names=None, storage_name=None, available_statuses=None, not_available_statuses=None):  # noqa: E501
        """BusinessObjectDataAvailability - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value_filters = None
        self._partition_value_filter = None
        self._business_object_data_version = None
        self._business_object_data_status = None
        self._storage_names = None
        self._storage_name = None
        self._available_statuses = None
        self._not_available_statuses = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if partition_value_filters is not None:
            self.partition_value_filters = partition_value_filters
        if partition_value_filter is not None:
            self.partition_value_filter = partition_value_filter
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if business_object_data_status is not None:
            self.business_object_data_status = business_object_data_status
        if storage_names is not None:
            self.storage_names = storage_names
        if storage_name is not None:
            self.storage_name = storage_name
        if available_statuses is not None:
            self.available_statuses = available_statuses
        if not_available_statuses is not None:
            self.not_available_statuses = not_available_statuses

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataAvailability.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataAvailability.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataAvailability.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataAvailability.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataAvailability.  # noqa: E501

        The Usage of a Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataAvailability.

        The Usage of a Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataAvailability.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataAvailability.

        A File Type known to the system that describes the file type of data stored under a Business Object Format  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataAvailability.  # noqa: E501

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :return: The business_object_format_version of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataAvailability.

        The Business Object Format Version for a previously registered Business Object Format  # noqa: E501

        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataAvailability.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value_filters(self):
        """Gets the partition_value_filters of this BusinessObjectDataAvailability.  # noqa: E501

        A container for Partition Value Filters  # noqa: E501

        :return: The partition_value_filters of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: list[PartitionValueFilter]
        """
        return self._partition_value_filters

    @partition_value_filters.setter
    def partition_value_filters(self, partition_value_filters):
        """Sets the partition_value_filters of this BusinessObjectDataAvailability.

        A container for Partition Value Filters  # noqa: E501

        :param partition_value_filters: The partition_value_filters of this BusinessObjectDataAvailability.  # noqa: E501
        :type: list[PartitionValueFilter]
        """

        self._partition_value_filters = partition_value_filters

    @property
    def partition_value_filter(self):
        """Gets the partition_value_filter of this BusinessObjectDataAvailability.  # noqa: E501


        :return: The partition_value_filter of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: PartitionValueFilter
        """
        return self._partition_value_filter

    @partition_value_filter.setter
    def partition_value_filter(self, partition_value_filter):
        """Sets the partition_value_filter of this BusinessObjectDataAvailability.


        :param partition_value_filter: The partition_value_filter of this BusinessObjectDataAvailability.  # noqa: E501
        :type: PartitionValueFilter
        """

        self._partition_value_filter = partition_value_filter

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataAvailability.  # noqa: E501

        The numeric version of a Business Object Data  # noqa: E501

        :return: The business_object_data_version of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataAvailability.

        The numeric version of a Business Object Data  # noqa: E501

        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataAvailability.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def business_object_data_status(self):
        """Gets the business_object_data_status of this BusinessObjectDataAvailability.  # noqa: E501

        A Business Object Data Status value specified in the request for available Business Object Data  # noqa: E501

        :return: The business_object_data_status of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._business_object_data_status

    @business_object_data_status.setter
    def business_object_data_status(self, business_object_data_status):
        """Sets the business_object_data_status of this BusinessObjectDataAvailability.

        A Business Object Data Status value specified in the request for available Business Object Data  # noqa: E501

        :param business_object_data_status: The business_object_data_status of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """

        self._business_object_data_status = business_object_data_status

    @property
    def storage_names(self):
        """Gets the storage_names of this BusinessObjectDataAvailability.  # noqa: E501

        A container for Storage Names to include when checking for Business Object Data availability  # noqa: E501

        :return: The storage_names of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_names

    @storage_names.setter
    def storage_names(self, storage_names):
        """Sets the storage_names of this BusinessObjectDataAvailability.

        A container for Storage Names to include when checking for Business Object Data availability  # noqa: E501

        :param storage_names: The storage_names of this BusinessObjectDataAvailability.  # noqa: E501
        :type: list[str]
        """

        self._storage_names = storage_names

    @property
    def storage_name(self):
        """Gets the storage_name of this BusinessObjectDataAvailability.  # noqa: E501

        Name of an existing storage known to the System. Required when StorageName is present  # noqa: E501

        :return: The storage_name of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this BusinessObjectDataAvailability.

        Name of an existing storage known to the System. Required when StorageName is present  # noqa: E501

        :param storage_name: The storage_name of this BusinessObjectDataAvailability.  # noqa: E501
        :type: str
        """

        self._storage_name = storage_name

    @property
    def available_statuses(self):
        """Gets the available_statuses of this BusinessObjectDataAvailability.  # noqa: E501

        A container for the Business Object Data in this query that are considered available  # noqa: E501

        :return: The available_statuses of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: list[BusinessObjectDataStatus]
        """
        return self._available_statuses

    @available_statuses.setter
    def available_statuses(self, available_statuses):
        """Sets the available_statuses of this BusinessObjectDataAvailability.

        A container for the Business Object Data in this query that are considered available  # noqa: E501

        :param available_statuses: The available_statuses of this BusinessObjectDataAvailability.  # noqa: E501
        :type: list[BusinessObjectDataStatus]
        """

        self._available_statuses = available_statuses

    @property
    def not_available_statuses(self):
        """Gets the not_available_statuses of this BusinessObjectDataAvailability.  # noqa: E501

        A container for the Business Object Data in this query that are not considered available  # noqa: E501

        :return: The not_available_statuses of this BusinessObjectDataAvailability.  # noqa: E501
        :rtype: list[BusinessObjectDataStatus]
        """
        return self._not_available_statuses

    @not_available_statuses.setter
    def not_available_statuses(self, not_available_statuses):
        """Sets the not_available_statuses of this BusinessObjectDataAvailability.

        A container for the Business Object Data in this query that are not considered available  # noqa: E501

        :param not_available_statuses: The not_available_statuses of this BusinessObjectDataAvailability.  # noqa: E501
        :type: list[BusinessObjectDataStatus]
        """

        self._not_available_statuses = not_available_statuses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataAvailability):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrPigStep(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'namespace': 'str',
        'emr_cluster_definition_name': 'str',
        'emr_cluster_name': 'str',
        'step_name': 'str',
        'script_location': 'str',
        'script_arguments': 'list[str]',
        'continue_on_error': 'bool',
        'emr_cluster_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'namespace': 'namespace',
        'emr_cluster_definition_name': 'emrClusterDefinitionName',
        'emr_cluster_name': 'emrClusterName',
        'step_name': 'stepName',
        'script_location': 'scriptLocation',
        'script_arguments': 'scriptArguments',
        'continue_on_error': 'continueOnError',
        'emr_cluster_id': 'emrClusterId'
    }

    def __init__(self, id=None, namespace=None, emr_cluster_definition_name=None, emr_cluster_name=None, step_name=None, script_location=None, script_arguments=None, continue_on_error=None, emr_cluster_id=None):  # noqa: E501
        """EmrPigStep - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._namespace = None
        self._emr_cluster_definition_name = None
        self._emr_cluster_name = None
        self._step_name = None
        self._script_location = None
        self._script_arguments = None
        self._continue_on_error = None
        self._emr_cluster_id = None
        self.discriminator = None

        self.id = id
        self.namespace = namespace
        self.emr_cluster_definition_name = emr_cluster_definition_name
        self.emr_cluster_name = emr_cluster_name
        self.step_name = step_name
        self.script_location = script_location
        if script_arguments is not None:
            self.script_arguments = script_arguments
        if continue_on_error is not None:
            self.continue_on_error = continue_on_error
        if emr_cluster_id is not None:
            self.emr_cluster_id = emr_cluster_id

    @property
    def id(self):
        """Gets the id of this EmrPigStep.  # noqa: E501


        :return: The id of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmrPigStep.


        :param id: The id of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def namespace(self):
        """Gets the namespace of this EmrPigStep.  # noqa: E501


        :return: The namespace of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this EmrPigStep.


        :param namespace: The namespace of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def emr_cluster_definition_name(self):
        """Gets the emr_cluster_definition_name of this EmrPigStep.  # noqa: E501


        :return: The emr_cluster_definition_name of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._emr_cluster_definition_name

    @emr_cluster_definition_name.setter
    def emr_cluster_definition_name(self, emr_cluster_definition_name):
        """Sets the emr_cluster_definition_name of this EmrPigStep.


        :param emr_cluster_definition_name: The emr_cluster_definition_name of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if emr_cluster_definition_name is None:
            raise ValueError("Invalid value for `emr_cluster_definition_name`, must not be `None`")  # noqa: E501

        self._emr_cluster_definition_name = emr_cluster_definition_name

    @property
    def emr_cluster_name(self):
        """Gets the emr_cluster_name of this EmrPigStep.  # noqa: E501


        :return: The emr_cluster_name of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._emr_cluster_name

    @emr_cluster_name.setter
    def emr_cluster_name(self, emr_cluster_name):
        """Sets the emr_cluster_name of this EmrPigStep.


        :param emr_cluster_name: The emr_cluster_name of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if emr_cluster_name is None:
            raise ValueError("Invalid value for `emr_cluster_name`, must not be `None`")  # noqa: E501

        self._emr_cluster_name = emr_cluster_name

    @property
    def step_name(self):
        """Gets the step_name of this EmrPigStep.  # noqa: E501


        :return: The step_name of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._step_name

    @step_name.setter
    def step_name(self, step_name):
        """Sets the step_name of this EmrPigStep.


        :param step_name: The step_name of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if step_name is None:
            raise ValueError("Invalid value for `step_name`, must not be `None`")  # noqa: E501

        self._step_name = step_name

    @property
    def script_location(self):
        """Gets the script_location of this EmrPigStep.  # noqa: E501


        :return: The script_location of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._script_location

    @script_location.setter
    def script_location(self, script_location):
        """Sets the script_location of this EmrPigStep.


        :param script_location: The script_location of this EmrPigStep.  # noqa: E501
        :type: str
        """
        if script_location is None:
            raise ValueError("Invalid value for `script_location`, must not be `None`")  # noqa: E501

        self._script_location = script_location

    @property
    def script_arguments(self):
        """Gets the script_arguments of this EmrPigStep.  # noqa: E501


        :return: The script_arguments of this EmrPigStep.  # noqa: E501
        :rtype: list[str]
        """
        return self._script_arguments

    @script_arguments.setter
    def script_arguments(self, script_arguments):
        """Sets the script_arguments of this EmrPigStep.


        :param script_arguments: The script_arguments of this EmrPigStep.  # noqa: E501
        :type: list[str]
        """

        self._script_arguments = script_arguments

    @property
    def continue_on_error(self):
        """Gets the continue_on_error of this EmrPigStep.  # noqa: E501


        :return: The continue_on_error of this EmrPigStep.  # noqa: E501
        :rtype: bool
        """
        return self._continue_on_error

    @continue_on_error.setter
    def continue_on_error(self, continue_on_error):
        """Sets the continue_on_error of this EmrPigStep.


        :param continue_on_error: The continue_on_error of this EmrPigStep.  # noqa: E501
        :type: bool
        """

        self._continue_on_error = continue_on_error

    @property
    def emr_cluster_id(self):
        """Gets the emr_cluster_id of this EmrPigStep.  # noqa: E501


        :return: The emr_cluster_id of this EmrPigStep.  # noqa: E501
        :rtype: str
        """
        return self._emr_cluster_id

    @emr_cluster_id.setter
    def emr_cluster_id(self, emr_cluster_id):
        """Sets the emr_cluster_id of this EmrPigStep.


        :param emr_cluster_id: The emr_cluster_id of this EmrPigStep.  # noqa: E501
        :type: str
        """

        self._emr_cluster_id = emr_cluster_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrPigStep):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_format_api import BusinessObjectFormatApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectFormatApi(unittest.TestCase):
    """BusinessObjectFormatApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_format_api.BusinessObjectFormatApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_format_create_business_object_format(self):
        """Test case for business_object_format_create_business_object_format

        createBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_delete_business_object_format(self):
        """Test case for business_object_format_delete_business_object_format

        deleteBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_generate_business_object_format_ddl(self):
        """Test case for business_object_format_generate_business_object_format_ddl

        generateBusinessObjectFormatDdl  # noqa: E501
        """
        pass

    def test_business_object_format_generate_business_object_format_ddl_collection(self):
        """Test case for business_object_format_generate_business_object_format_ddl_collection

        generateBusinessObjectFormatDdlCollection  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_format(self):
        """Test case for business_object_format_get_business_object_format

        getBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_formats(self):
        """Test case for business_object_format_get_business_object_formats

        getBusinessObjectFormats  # noqa: E501
        """
        pass

    def test_business_object_format_get_business_object_formats_with_filters(self):
        """Test case for business_object_format_get_business_object_formats_with_filters

        getBusinessObjectFormatsWithFilters  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format(self):
        """Test case for business_object_format_update_business_object_format

        updateBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_attribute_definitions(self):
        """Test case for business_object_format_update_business_object_format_attribute_definitions

        updateBusinessObjectFormatAttributeDefinitions  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_attributes(self):
        """Test case for business_object_format_update_business_object_format_attributes

        updateBusinessObjectFormatAttributes  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_legal_hold(self):
        """Test case for business_object_format_update_business_object_format_legal_hold

        updateBusinessObjectFormatLegalHold  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_parents(self):
        """Test case for business_object_format_update_business_object_format_parents

        updateBusinessObjectFormatParents  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_record_flag(self):
        """Test case for business_object_format_update_business_object_format_record_flag

        updateBusinessObjectFormatRecordFlag  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_retention_information(self):
        """Test case for business_object_format_update_business_object_format_retention_information

        updateBusinessObjectFormatRetentionInformation  # noqa: E501
        """
        pass

    def test_business_object_format_update_business_object_format_schema_backwards_compatible_changes(self):
        """Test case for business_object_format_update_business_object_format_schema_backwards_compatible_changes

        updateBusinessObjectFormatSchemaBackwardsCompatibleChanges  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_attribute_api import BusinessObjectDataAttributeApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataAttributeApi(unittest.TestCase):
    """BusinessObjectDataAttributeApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_attribute_api.BusinessObjectDataAttributeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_attribute_create_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_create_business_object_data_attribute

        createBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute1

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute2

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute3

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_delete_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_delete_business_object_data_attribute4

        deleteBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute1

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute2

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute3

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_get_business_object_data_attribute4

        getBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes1(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes1

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes2(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes2

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes3(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes3

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_get_business_object_data_attributes4(self):
        """Test case for business_object_data_attribute_get_business_object_data_attributes4

        getBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute1(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute1

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute2(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute2

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute3(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute3

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass

    def test_business_object_data_attribute_update_business_object_data_attribute4(self):
        """Test case for business_object_data_attribute_update_business_object_data_attribute4

        updateBusinessObjectDataAttribute  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
